/**
 * initApp handles setting up UI event listeners and registering Firebase auth listeners:
 *  - firebase.auth().onAuthStateChanged: This listener is called when the user is signed in or
 *    out, and that is where we update the UI.
 */

let email;
let uid;

function initApp() {
    // Listening for auth state changes.
    // [START authstatelistener]
    firebase.auth().onAuthStateChanged(function (user) {
        if (user) {
            // User is signed in.

            email = user.email;
            let emailVerified = user.emailVerified;
            uid = user.uid;
            let providerData = user.providerData;

            // console.log(email)
            let db = firebase.firestore();


            let docRef = db.collection("admins").doc(uid);

            docRef.get().then(function (doc) {
                if (doc.exists) {
                    console.log("Document data:", doc.data());
                    let type = doc.data().typeId;
                    if (type === 1) {
                        window.location.href = 'dashboard.html'
                    } else if (type === 2) {

                    } else if (type === 3) {

                    }


                } else {
                    Swal.fire({
                        icon: 'error',
                        title: 'Oops...',
                        text: 'You do not have access to this platform.'

                    });
                    document.getElementById('signInBtn').disabled = false;
                    $('#signInBtn').html(' <button class="btn btn-danger mt-10" id="signInBtn" onclick="toggleSignIn()" type="submit">Log In\n' +
                        '</button>').attr('disabled', false);
                    toggleSignOut()
                    // doc.data() will be undefined in this case
                    console.log("No such document!");
                }
            }).catch(function (error) {
                console.log("Error getting document:", error);
            });



        } else {
            // User is signed out.
            console.log("User is signed out");

        }

    });
    // [END authstatelistener]

}

window.onload = function () {
    initApp();
};


/**
 * Handles the sign in button press.
 */
function toggleSignIn() {

    $('#signInBtn').html('<span class="spinner-border spinner-border-sm mr-2" role="status" aria-hidden="true"></span>Loading...').attr('disabled', true);


    document.getElementById('signInBtn').disabled = true;
    var email = document.getElementById('email').value;
    var password = document.getElementById('password').value;
    if (email.length < 4) {
        document.getElementById('signInBtn').disabled = false;
        $('#signInBtn').html(' <button class="btn btn-danger mt-10" id="signInBtn" onclick="toggleSignIn()" type="submit">Log In\n' +
            '                        </button>').attr('disabled', false);

        Swal.fire({
            icon: 'error',
            title: 'Oops...',
            text: 'Please enter a valid email address.'

        })
        return;
    }
    if (password.length < 6) {
        document.getElementById('signInBtn').disabled = false;
        $('#signInBtn').html(' <button class="btn btn-danger mt-10" id="signInBtn" onclick="toggleSignIn()" type="submit">Log In\n' +
            '                        </button>').attr('disabled', false);
        Swal.fire({
            icon: 'error',
            title: 'Oops...',
            text: 'Password is too short.'

        })
        return;
    }
    // Sign in with email and pass.
    // [START authwithemail]
    firebase.auth().signInWithEmailAndPassword(email, password).catch(function (error) {
        document.getElementById('signInBtn').disabled = false;
        $('#signInBtn').html(' <button class="btn btn-danger mt-10" id="signInBtn" onclick="toggleSignIn()" type="submit">Sign In\n' +
            '                        </button>').attr('disabled', false);
        // Handle Errors here.
        var errorCode = error.code;
        var errorMessage = error.message;
        // [START_EXCLUDE]
        if (errorCode === 'auth/wrong-password') {

            Swal.fire({
                icon: 'error',
                title: 'Oops...',
                text: 'Wrong password.'

            })

        } else {

            Swal.fire({
                icon: 'error',
                title: 'Oops...',
                text: errorMessage

            })

        }

        console.log(error);

        // [END_EXCLUDE]
    });
    // [END authwithemail]
}
function toggleSignOut() {

    // [START signout]
    firebase.auth().signOut();
    // [END signout]

}

$(document).on("keydown", function (e) {

    var keyCode = e.which || e.keyCode;
    if (keyCode == 13) // enter key code
    {
        toggleSignIn();
    }

});