/**
 * initApp handles setting up UI event listeners and registering Firebase auth listeners:
 *  - firebase.auth().onAuthStateChanged: This listener is called when the user is signed in or
 *    out, and that is where we update the UI.
 */

let email;
let uid;
let username;


var bs_modal = $('#modal');
var image = document.getElementById('image');
var cropper, reader, file;
let downloadUrl = ' ';


$("body").on("change", ".image", function (e) {
    var files = e.target.files;
    var done = function (url) {
        image.src = url;
        bs_modal.modal('show');
    };


    if (files && files.length > 0) {
        file = files[0];

        if (URL) {
            done(URL.createObjectURL(file));
        } else if (FileReader) {
            reader = new FileReader();
            reader.onload = function (e) {
                done(reader.result);
            };
            reader.readAsDataURL(file);
        }
    }
});

bs_modal.on('shown.bs.modal', function () {
    cropper = new Cropper(image, {
        aspectRatio: 1,
        viewMode: 1,
        preview: '.preview'
    });
}).on('hidden.bs.modal', function () {
    cropper.destroy();
    cropper = null;
});

$("#crop").click(function () {
    document.getElementById('crop').disabled = true;

    canvas = cropper.getCroppedCanvas({
        width: 200,
        height: 200,
    });

    canvas.toBlob(function (blob) {
        url = URL.createObjectURL(blob);
        let imPreview = document.getElementById("imgPreview");

        

        var reader = new FileReader();
        reader.readAsDataURL(blob);
        reader.onloadend = function () {
            var base64data = reader.result;
            console.log(base64data);
            // Get a reference to the storage service, which is used to create references in your storage bucket
            const storage = firebase.storage();

            // Create a storage reference from our storage service
            const storageRef = storage.ref();
            storageRef.child('restaurants/' + generateUUID()).putString(base64data, 'data_url').then((snapshot) => {
                snapshot.ref.getDownloadURL().then(function (downloadURL) {
                    console.log('File available at', downloadURL);
                    downloadUrl = downloadURL;
                    imPreview.src = downloadURL;
                    document.getElementById('crop').disabled = false;

                    bs_modal.modal('hide');

                }).catch(function (error) {
                    document.getElementById('crop').disabled = false;

                    console.log("Error getting document:", error);
                });
                console.log('Uploaded a data_url string!');
            });



        };
    });
});

function initApp() {
    // Listening for auth state changes.
    // [START authstatelistener]
    firebase.auth().onAuthStateChanged(function (user) {
        if (user) {
            // User is signed in.

            email = user.email;
            let emailVerified = user.emailVerified;
            uid = user.uid;
            let providerData = user.providerData;

            // console.log(email)
            let db = firebase.firestore();


            let docRef = db.collection("admins").doc(uid);

            docRef.get().then(function (doc) {
                if (doc.exists) {
                    console.log("Document data:", doc.data());
                    let type = doc.data().typeId;
                    username = doc.data().name;
                    if (type === 1) {

                        document.getElementById('proName').innerText = username;
                    } else if (type === 2) {

                    } else if (type === 3) {

                    }


                } else {
                    Swal.fire({
                        icon: 'error',
                        title: 'Oops...',
                        text: 'You do not have access to this platform.'

                    });
                    toggleSignOut()
                    // doc.data() will be undefined in this case
                    console.log("No such document!");
                }
            }).catch(function (error) {
                console.log("Error getting document:", error);
            });



        } else {
            // User is signed out.
            console.log("User is signed out");
            window.location.href = 'index.html'

        }

    });
    // [END authstatelistener]

}
function initMap() {
    const center = { lat: 50.064192, lng: -130.605469 };
    // Create a bounding box with sides ~10km away from the center point
    const defaultBounds = {
        north: center.lat + 0.1,
        south: center.lat - 0.1,
        east: center.lng + 0.1,
        west: center.lng - 0.1,
    };
    const input = document.getElementById("storeAddress");
    const options = {
        bounds: defaultBounds,

        fields: ["geometry", "name", "formatted_address"],
        origin: center,
        strictBounds: false,
        types: ["establishment"],
    };
    autocomplete = new google.maps.places.Autocomplete(input, options);
    autocomplete.addListener("place_changed", fillInAddress);
    var mapProp= {
        center:new google.maps.LatLng(-24.653257,25.906792),
        zoom:10,
        mapTypeId: google.maps.MapTypeId.ROADMAP,
      };
      var map = new google.maps.Map(document.getElementById("googleMap"),mapProp);
}
window.onload = function () {
    initApp();
};
let placeSearch;
let autocomplete;
let lat;
let lng;
let restAddress;
let db = firebase.firestore();
function fillInAddress() {
    // Get the place details from the autocomplete object.
    const place = autocomplete.getPlace();
    console.log(place);

    lat = place.geometry.location.lat();
    // get lng
    lng = place.geometry.location.lng();
    restAddress = place.name + ", " + place.formatted_address;

    console.log(lat + " " + lng + " " + restAddress);
    var mapProp= {
        center:new google.maps.LatLng(lat,lng),
        zoom:18,
        mapTypeId: google.maps.MapTypeId.ROADMAP,
      };
      var map = new google.maps.Map(document.getElementById("googleMap"),mapProp);
      var marker = new google.maps.Marker({
        position:new google.maps.LatLng(lat,lng),
        
      });
      
      marker.setMap(map);
}


function toggleSignOut() {

    // [START signout]
    firebase.auth().signOut();
    // [END signout]

}

$(document).on("keydown", function (e) {

    var keyCode = e.which || e.keyCode;
    if (keyCode == 13) // enter key code
    {
        toggleSignIn();
    }

});

$(document).ready(function () {
    $("#restCat").select2();
    $("#cuisineType").select2();
    
});

//let file = 'null';


function generateUUID() { // Public Domain/MIT
    var d = new Date().getTime();//Timestamp
    var d2 = (performance && performance.now && (performance.now() * 1000)) || 0;//Time in microseconds since page-load or 0 if unsupported
    return 'xxxxxxxx-xxxx-4xxx-yxxx-xxxxxxxxxxxx'.replace(/[xy]/g, function (c) {
        var r = Math.random() * 16;//random number between 0 and 16
        if (d > 0) {//Use timestamp until depleted
            r = (d + r) % 16 | 0;
            d = Math.floor(d / 16);
        } else {//Use microseconds since page-load if supported
            r = (d2 + r) % 16 | 0;
            d2 = Math.floor(d2 / 16);
        }
        return (c === 'x' ? r : (r & 0x3 | 0x8)).toString(16);
    });
}
let stBaking = " ";
let stOils = " ";
let stCondiments = " ";
let stNuts = " ";
let stDelCond = " ";
let stKnockDown = " ";
let stFloor = " ";


function addRest() {



    let stCategoryIds = $('#restCat').select2("val");
    let stCategory = $('#restCat').select2("data");
    let categoryArray = []
    for (let j = 0; j < stCategory.length; j++) {
        categoryArray.push(stCategory[j].text)
    }

    let cuisineTypeIds = $('#cuisineType').select2("val");
    let cuisineType = $('#cuisineType').select2("data");
    let cuisineTypeArray = []
    for (let j = 0; j < cuisineType.length; j++) {
        cuisineTypeArray.push(cuisineType[j].text)
    }

    let stName = document.getElementById('stName').value;


    stFloor = document.getElementById('stFloor').value;
    let stPlot = document.getElementById('stPlot').value;

    // let status = document.getElementById('active').value;
    let stFName = document.getElementById('stFName').value;
    let stLName = document.getElementById('stLName').value;

    let stEmail = document.getElementById('stEmail').value;

    let stPhone = document.getElementById('stPhone').value;

    // stBaking = document.getElementById('stBaking').value;
    // stOils = document.getElementById('stOils').value;
    //  stNuts = document.getElementById('stNuts').value;
    // stCondiments = document.getElementById('stCondiments').value;
    // stDelCond = document.getElementById('stDelCond').value;
    // stKnockDown = document.getElementById('stKnockDown').value;

    let stImage = document.getElementById('findPhoto');

   




    if (stName.length < 1) {


        Swal.fire({
            icon: 'error',
            title: 'Oops...',
            text: 'Please enter a store name.'

        })
        return;
    }
    if (stPlot.length < 1) {


        Swal.fire({
            icon: 'error',
            title: 'Oops...',
            text: 'Please enter Plot.'

        })
        return;
    }
    if (stFName.length < 1) {


        Swal.fire({
            icon: 'error',
            title: 'Oops...',
            text: 'Please enter a first name.'

        })
        return;
    }
    if (stLName.length < 1) {


        Swal.fire({
            icon: 'error',
            title: 'Oops...',
            text: 'Please enter a last name.'

        })
        return;
    }
    console.log("lat", lat);
    console.log("restAddress", restAddress);
    if (lat === null || typeof restAddress === "undefined") {

        Swal.fire({
            icon: 'error',
            title: 'Oops...',
            text: 'Please choose a store address.'

        })
        return;
    }
    console.log("phone: " + stPhone + " isValid: " + phonenumberBst(stPhone));
    if (!phonenumberBst(stPhone)) {

        Swal.fire({
            icon: 'error',
            title: 'Oops...',
            text: 'Please enter a valid phone number'

        });
        return;
    }
    console.log("email: " + stEmail + " isValid: " + validateEmail(stEmail));
    if (!validateEmail(stEmail)) {

        Swal.fire({
            icon: 'error',
            title: 'Oops...',
            text: 'Please enter a valid email address'

        });
        return;
    }


    if (categoryArray.length === 0) {
        Swal.fire({
            icon: 'error',
            title: 'Oops...',
            text: 'Please enter restaurant category.'

        })
        return;
    }
    if (cuisineTypeArray.length === 0) {
        Swal.fire({
            icon: 'error',
            title: 'Oops...',
            text: 'Please enter cuisine type.'

        })

        return;
    }



    let statusCode;
    let state;
    if (document.getElementById('radio1').checked) {
        statusCode = document.getElementById('radio1').value;
        state = "Published";

    } else if (document.getElementById('radio2').checked) {
        statusCode = document.getElementById('radio2').value;
        state = "Draft";
    }
    

    $('#stAddRest').html('<span class="spinner-border spinner-border-sm mr-2" role="status" aria-hidden="true"></span>Loading...').attr('disabled', true);

    document.getElementById('stAddRest').disabled = true;
    return $.ajax({
        url: 'https://us-central1-dotdelivery-fbd89.cloudfunctions.net/createAdministrator',
        data: JSON.stringify({
            name: stName,
            
            photoUrl: downloadUrl,
            email: stEmail,
        }),
        processData: false,
        contentType: "application/json",
        type: 'POST',
        success: function (data) {
            console.log(JSON.stringify(data));
           
            if (data.status === 0) {
                $('#stAddRest').html('<button type="stAddRest" class="btn btn-primary" id="stAddRest" onclick="addRest()">Save</button>\n').attr('disabled', false);
                Swal.fire({
                    icon: 'error',
                    title: 'Oops...',
                    text: data.data.message

                });


            } else if (data.status === 1) {
                let traderUid = data.data.uid;

                let restId = db.collection("restaurants").doc().id;
                let adminArray = [traderUid];
                console.log(adminArray + " " + restId);
                // Add a new document with a generated id.
                return db.collection("restaurants").doc(restId).set({
                    status: state,
                    restId: restId,
                    statusCode: statusCode,
                    restaurant: stName,
                    restAddress: restAddress,
                    restFloor: stFloor,
                    restPlot: stPlot,
                    managerFirstName: stFName,
                    restCategories: categoryArray,
                    restCategoriesIds: stCategoryIds,
                    cuisineTypeIds: cuisineTypeIds,
                    cuisineTypeArray: cuisineTypeArray,
                    managerLastName: stLName,
                    managerFullName: stFName + " " + stLName,
                    restEmail: stEmail,
                    restPhone: stPhone,
                    latitude: lat,
                    longitude: lng,
                    createdByName: username,
                    adminUid: traderUid,
                    tradersIdArray: adminArray,
                    createdBy: uid,
                    createdByEmail: email,
                    restImg: downloadUrl,
                    timestamp: firebase.firestore.FieldValue.serverTimestamp(),
                })
                    .then(function () {
                        console.log("Document written ");


                        return db.collection("traders").doc(traderUid).set({
                            status: "active",
                            restId: restId,
                            statusCode: 1,
                            restaurant: stName,
                            traderFirstName: stFName,
                            traderLastName: stLName,
                            traderFullName: stFName + " " + stLName,
                            createdByName: username,
                            traderId: traderUid,
                            createdBy: uid,
                            createdByEmail: email,
                            restImg: downloadUrl,
                            timestamp: firebase.firestore.FieldValue.serverTimestamp(),

                        })
                            .then(function () {
                                console.log("Document written ");
                                Swal.fire({
                                    icon: 'success',
                                    title: 'Success',
                                    text: 'You have successfully created a new restaurant.'

                                }).then((result) => {
                                    window.location.href = 'shops.html'
                                })
                            })
                            .catch(function (error) {
                                $('#stAddRest').html('<button type="button" class="btn btn-primary" id="stAddRest" onclick="addRest()">Save</button>\n').attr('disabled', false);
                                console.error("Error adding document: ", error);
                                Swal.fire({
                                    icon: 'error',
                                    title: 'Oops...',
                                    text: error

                                }).then((result) => {

                                })
                            });
                    })
                    .catch(function (error) {
                        $('#stAddRest').html('<button type="button" class="btn btn-primary" id="stAddRest" onclick="addRest()">Save</button>\n').attr('disabled', false);
                        console.error("Error adding document: ", error);
                        Swal.fire({
                            icon: 'error',
                            title: 'Oops...',
                            text: error

                        }).then((result) => {

                        })
                    });
            }
        }
    })

}


function phonenumberBst(inputtxt) {
    var phoneno = /^\+?([0-9]{11})$/;
    if ((inputtxt.match(phoneno))) {
        return true;
    }
    else {

        return phonenumberKe(inputtxt);
    }
}
function phonenumberKe(inputtxt) {
    var phoneno = /^\+?([0-9]{12})$/;
    if ((inputtxt.match(phoneno))) {
        return true;
    }
    else {

        return false;
    }
}

function validateEmail(email) {
    const re = /^(([^<>()[\]\\.,;:\s@"]+(\.[^<>()[\]\\.,;:\s@"]+)*)|(".+"))@((\[[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\])|(([a-zA-Z\-0-9]+\.)+[a-zA-Z]{2,}))$/;
    return re.test(String(email).toLowerCase());
}