/**
 * initApp handles setting up UI event listeners and registering Firebase auth listeners:
 *  - firebase.auth().onAuthStateChanged: This listener is called when the user is signed in or
 *    out, and that is where we update the UI.
 */

 let email;
 let uid;
 
 let traderName;
 let updateId;
 let db;
 
 
 
 
 function initApp() {
     // Listening for auth state changes.
     // [START authstatelistener]
     firebase.auth().onAuthStateChanged(function (user) {
         if (user) {
             // User is signed in.
 
             email = user.email;
             let emailVerified = user.emailVerified;
             uid = user.uid;
             traderName = user.displayName;
             let providerData = user.providerData;
 
              console.log(traderName)
             db = firebase.firestore();
 
 
             let docRef = db.collection("restaurants");
 
             docRef.get().then((querySnapshot) => {
                 querySnapshot.forEach((doc) => {
                     // doc.data() is never undefined for query doc snapshots
                     console.log(doc.id, " => ", doc.data());
                    let  restName = doc.data().restaurant;
                    let restId = doc.data().restId;
                 
                
                     document.getElementById('proName').innerText = traderName + " (" + restName + ")";
                     db.collection("orders").where("restId", "==", restId).orderBy('timestamp', 'desc').onSnapshot((snapshot) => {
                        $("#orders tbody").empty();
                         snapshot.forEach(function (document) {
                         

                            let orderNo = document.data().orderNumber;
                             let branch = document.data().branch;
                             let branchAddress = document.data().branchAddress;
                             let displayName = document.data().displayName;
                             let userPhone = document.data().userPhone;
                             let timestamp = document.data().timestamp;
                             let noOfItems = document.data().noOfItems;
                             let total = document.data().total;
                             let deliveryAddress = document.data().deliveryAddress;
                            let orderStatus = document.data().orderStatus;
                            let orderStatusId = document.data().orderStatusId;
         
                             var body = "<tr>";
         
                             body += "<td>" + orderNo+ "</td>";
                             body += "<td>" + timestamp.toDate() + "</td>";
                             body += "<td>" + branch + "</td>";
                             body += "<td>" + branchAddress + "</td>";
                             body += "<td>" + displayName+ " ("+ userPhone+")"+ "</td>";
                             body += "<td>" + noOfItems + "</td>";
                             body += "<td>" + total + "</td>";
                             body += "<td>" + deliveryAddress + "</td>";
                             body += "<td>" + orderStatus + "</td>";
                             
                             body += "</tr>"
                             $("#orders tbody").append(body);
                         });
                         if ( ! $.fn.DataTable.isDataTable( '#orders' ) ) {
                         $('#orders').DataTable({
                             dom: 'Bfrtip',
                             buttons: [
                                 'copy', 'csv', 'excel', 'pdf', 'print'
                             ]
                         });
                        }
                     });
 
                  
                 });
         
                    
             }).catch(function (error) {
                 console.log("Error getting document:", error);
             });
 
           
 
 
 
 
 
 
 
 
         } else {
             // User is signed out.
             console.log("User is signed out");
             window.location.href = 'index.html'
 
         }
 
     });
     // [END authstatelistener]
 
 }
 
 window.onload = function () {
     initApp();
 };
 $(document).ready(function () {
    $("#changeStatus").select2();
    
});
 
 
 function toggleSignOut() {
 
     // [START signout]
     firebase.auth().signOut();
     // [END signout]
 
 }
 
 $(document).on("keydown", function (e) {
 
     var keyCode = e.which || e.keyCode;
     if (keyCode == 13) // enter key code
     {
         toggleSignIn();
     }
 
 });

 function orderStatus(id){
     updateId = id;
 }
 function orderCancel(id){
    updateId = id;
}
 
 
 function openDetails(id) {
 
     window.location.href = "order_details.html?orderId=" + id
 
 }

 function updateStatus() {
    $('#stChangeStatus').html('<span class="spinner-border spinner-border-sm mr-2" role="status" aria-hidden="true"></span>Loading...').attr('disabled', true);

    document.getElementById('stChangeStatus').disabled = true;

    let statusId = document.getElementById('changeStatus').value;
    let status = $('#changeStatus').select2("data")[0].text;


    console.log(status+ " "+ statusId);

   
  
    

        
    return db.collection("orders").doc(updateId).update({
         
           
            orderStatus: status,
            orderStatusId:parseInt(statusId),
            updatedOn: firebase.firestore.FieldValue.serverTimestamp(),
            updatedBy: uid,
            updatedByName: traderName,
            updatedByEmail: email
        })
            .then(function () {
                console.log("Document updated ");
                Swal.fire({
                    icon: 'success',
                    title: 'Success',
                    text: 'Order Successfully updated.'

                }).then((result) => {
                   // window.location.href = 'menu_list.html'
                   $('#modal-default').modal('hide');
                })
            })
            .catch(function (error) {
                document.getElementById('stChangeStatus').disabled = false;
                $('#stChangeStatus').html('<button type="button" class="btn btn-primary" id="stChangeStatus" onclick="updateStatus()">Save</button>\n').attr('disabled', false);
                Swal.fire({
                    icon: 'error',
                    title: 'Oops...',
                    text: error

                }).then((result) => {
                    $('#modal-default').modal('hide');

                })
            });

   


}


function cancelOrder() {
    $('#stCancelOrder').html('<span class="spinner-border spinner-border-sm mr-2" role="status" aria-hidden="true"></span>Loading...').attr('disabled', true);

    document.getElementById('stCancelOrder').disabled = true;

    let reason = document.getElementById('reason').value;
    


    

   
  
    

        
    return db.collection("orders").doc(updateId).update({
         
           
            orderStatus: "Cancelled",
            orderStatusId:4,
            deliveryStatusId: 4,
            deliveryStatus: "Cancelled",
            cancellationReason: reason,
            cancelledOn: firebase.firestore.FieldValue.serverTimestamp(),
            cancelledBy: uid,
            cancelledByName: traderName,
            cancelledByEmail: email
        })
            .then(function () {
                console.log("Document updated ");
                Swal.fire({
                    icon: 'success',
                    title: 'Success',
                    text: 'Order Cancelled.'

                }).then((result) => {
                   // window.location.href = 'menu_list.html'
                   $('#modal-cancel').modal('hide');
                })
            })
            .catch(function (error) {
                document.getElementById('stCancelOrder').disabled = false;
                $('#stCancelOrder').html('<button type="button" class="btn btn-primary" id="stCancelOrder" onclick="cancelOrder()">Save</button>\n').attr('disabled', false);
                Swal.fire({
                    icon: 'error',
                    title: 'Oops...',
                    text: error

                }).then((result) => {
                    $('#modal-cancel').modal('hide');

                })
            });

   


}

